==> paraview-5.10.1-9-x86_64.pkg.tar.zst: opt/paraview/include/paraview/vtkPVVTKExtensionsFiltersRenderingModule.h <==

#ifndef VTKPVVTKEXTENSIONSFILTERSRENDERING_EXPORT_H
#define VTKPVVTKEXTENSIONSFILTERSRENDERING_EXPORT_H

#ifdef VTKPVVTKEXTENSIONSFILTERSRENDERING_STATIC_DEFINE
#  define VTKPVVTKEXTENSIONSFILTERSRENDERING_EXPORT
#  define VTKPVVTKEXTENSIONSFILTERSRENDERING_NO_EXPORT
#else
#  ifndef VTKPVVTKEXTENSIONSFILTERSRENDERING_EXPORT
#    ifdef VTKExtensionsFiltersRendering_EXPORTS
        /* We are building this library */
#      define VTKPVVTKEXTENSIONSFILTERSRENDERING_EXPORT __attribute__((visibility("default")))
#    else
        /* We are using this library */
#      define VTKPVVTKEXTENSIONSFILTERSRENDERING_EXPORT __attribute__((visibility("default")))
#    endif
#  endif

#  ifndef VTKPVVTKEXTENSIONSFILTERSRENDERING_NO_EXPORT
#    define VTKPVVTKEXTENSIONSFILTERSRENDERING_NO_EXPORT __attribute__((visibility("hidden")))
#  endif
#endif

#ifndef VTKPVVTKEXTENSIONSFILTERSRENDERING_DEPRECATED
#  define VTKPVVTKEXTENSIONSFILTERSRENDERING_DEPRECATED __attribute__ ((__deprecated__))
#endif

#ifndef VTKPVVTKEXTENSIONSFILTERSRENDERING_DEPRECATED_EXPORT
#  define VTKPVVTKEXTENSIONSFILTERSRENDERING_DEPRECATED_EXPORT VTKPVVTKEXTENSIONSFILTERSRENDERING_EXPORT VTKPVVTKEXTENSIONSFILTERSRENDERING_DEPRECATED
#endif

#ifndef VTKPVVTKEXTENSIONSFILTERSRENDERING_DEPRECATED_NO_EXPORT
#  define VTKPVVTKEXTENSIONSFILTERSRENDERING_DEPRECATED_NO_EXPORT VTKPVVTKEXTENSIONSFILTERSRENDERING_NO_EXPORT VTKPVVTKEXTENSIONSFILTERSRENDERING_DEPRECATED
#endif

#if 0 /* DEFINE_NO_DEPRECATED */
#  ifndef VTKPVVTKEXTENSIONSFILTERSRENDERING_NO_DEPRECATED
#    define VTKPVVTKEXTENSIONSFILTERSRENDERING_NO_DEPRECATED
#  endif
#endif

#endif /* VTKPVVTKEXTENSIONSFILTERSRENDERING_EXPORT_H */

==> paraview-5.12.1-4-x86_64.pkg.tar.zst: opt/paraview/include/paraview/vtkPVVTKExtensionsFiltersRenderingModule.h <==

#ifndef VTKPVVTKEXTENSIONSFILTERSRENDERING_EXPORT_H
#define VTKPVVTKEXTENSIONSFILTERSRENDERING_EXPORT_H

#ifdef VTKPVVTKEXTENSIONSFILTERSRENDERING_STATIC_DEFINE
#  define VTKPVVTKEXTENSIONSFILTERSRENDERING_EXPORT
#  define VTKPVVTKEXTENSIONSFILTERSRENDERING_NO_EXPORT
#else
#  ifndef VTKPVVTKEXTENSIONSFILTERSRENDERING_EXPORT
#    ifdef VTKExtensionsFiltersRendering_EXPORTS
        /* We are building this library */
#      define VTKPVVTKEXTENSIONSFILTERSRENDERING_EXPORT __attribute__((visibility("default")))
#    else
        /* We are using this library */
#      define VTKPVVTKEXTENSIONSFILTERSRENDERING_EXPORT __attribute__((visibility("default")))
#    endif
#  endif

#  ifndef VTKPVVTKEXTENSIONSFILTERSRENDERING_NO_EXPORT
#    define VTKPVVTKEXTENSIONSFILTERSRENDERING_NO_EXPORT __attribute__((visibility("hidden")))
#  endif
#endif

#ifndef VTKPVVTKEXTENSIONSFILTERSRENDERING_DEPRECATED
#  define VTKPVVTKEXTENSIONSFILTERSRENDERING_DEPRECATED __attribute__ ((__deprecated__))
#endif

#ifndef VTKPVVTKEXTENSIONSFILTERSRENDERING_DEPRECATED_EXPORT
#  define VTKPVVTKEXTENSIONSFILTERSRENDERING_DEPRECATED_EXPORT VTKPVVTKEXTENSIONSFILTERSRENDERING_EXPORT VTKPVVTKEXTENSIONSFILTERSRENDERING_DEPRECATED
#endif

#ifndef VTKPVVTKEXTENSIONSFILTERSRENDERING_DEPRECATED_NO_EXPORT
#  define VTKPVVTKEXTENSIONSFILTERSRENDERING_DEPRECATED_NO_EXPORT VTKPVVTKEXTENSIONSFILTERSRENDERING_NO_EXPORT VTKPVVTKEXTENSIONSFILTERSRENDERING_DEPRECATED
#endif

#if 0 /* DEFINE_NO_DEPRECATED */
#  ifndef VTKPVVTKEXTENSIONSFILTERSRENDERING_NO_DEPRECATED
#    define VTKPVVTKEXTENSIONSFILTERSRENDERING_NO_DEPRECATED
#  endif
#endif

/* VTK-HeaderTest-Exclude: vtkPVVTKExtensionsFiltersRenderingModule.h */

/* Include ABI Namespace */
#include "vtkABINamespace.h"

#endif /* VTKPVVTKEXTENSIONSFILTERSRENDERING_EXPORT_H */
